module Gem

  # An Array of the default sources that come with RubyGems.
  def self.default_sources
    %w[http://gems.rubyforge.org]
  end

  # Default home directory path to be used if an alternate value is not
  # specified in the environment.
	# 
	# Debian patch: search order of this directory.
	#   1. GEM_HOME enviroment variable
	#      (Using this, Gems are to be installed in any path as you like)
	#   2. /var/lib/gems/{ruby version} (This is the default path in Debian system)
	#
  def self.default_dir
    '/' + File.join('var', 'lib', 'gems', ConfigMap[:ruby_version])
  end

  # Default gem path.
  def self.default_path
    default_dir
  end

  # Deduce Ruby's --program-prefix and --program-suffix from its install name.
  def self.default_exec_format
    baseruby = ConfigMap[:BASERUBY] || 'ruby'
    ConfigMap[:RUBY_INSTALL_NAME].sub(baseruby, '%s') rescue '%s'
  end

  # The default directory for binaries
  def self.default_bindir
    Config::CONFIG['bindir']
  end

  # The default system-wide source info cache directory.
  def self.default_system_source_cache_dir
    File.join Gem.dir, 'source_cache'
  end

  # The default user-specific source info cache directory.
  def self.default_user_source_cache_dir
    File.join Gem.user_home, '.gem', 'source_cache'
  end

end

